Index: trunk/ppStack/src/ppStackLoop.h
===================================================================
--- trunk/ppStack/src/ppStackLoop.h	(revision 27400)
+++ trunk/ppStack/src/ppStackLoop.h	(revision 27402)
@@ -38,6 +38,6 @@
 // Prepare for combination
 bool ppStackCombinePrepare(
-    const char *outName,                // Name of output file
-    const char *expName,                // Name of exposure file
+    pmReadout **readout,                // Readout to set
+    const char *name,                   // Name of file
     ppStackFileList files,              // Files of interest
     ppStackThreadData *stack,           // Stack
@@ -61,4 +61,5 @@
 // Final combination
 bool ppStackCombineFinal(
+    pmReadout *target,                  // Target readout
     ppStackThreadData *stack,           // Stack
     psArray *covariances,               // Covariances
